@@ -4,12 +4,12 @@ cartographic projections and coordinate transformations library.
 
 Download: http://python.org/pypi/pyproj
 
-Requirements: Python 3.8+.
+Requirements: Python 10+.
 
 Contact:  Jeffrey Whitaker <jeffrey.s.whitaker@noaa.gov>
 
 Copyright (c) 2006-2018, Jeffrey Whitaker.
-Copyright (c) 2019-2022, Open source contributors.
+Copyright (c) 2019-2024, Open source contributors.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy of
 this software and associated documentation files (the "Software"), to deal in
@@ -28,16 +28,22 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
 SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
+
 import warnings
 
 import pyproj.network
-from pyproj._datadir import (  # noqa: F401 pylint: disable=unused-import
-    _pyproj_global_context_initialize,
+from pyproj._context import (  # noqa: F401 pylint: disable=unused-import
     set_use_global_context,
 )
 from pyproj._show_versions import (  # noqa: F401 pylint: disable=unused-import
     show_versions,
 )
+from pyproj._version import (  # noqa: F401 pylint: disable=unused-import
+    PROJ_COMPILED_VERSION,
+    PROJ_COMPILED_VERSION_STR,
+    PROJ_VERSION,
+    PROJ_VERSION_STR,
+)
 from pyproj.crs import CRS  # noqa: F401 pylint: disable=unused-import
 from pyproj.database import (  # noqa: F401 pylint: disable=unused-import
     get_authorities,
@@ -62,11 +68,10 @@ from pyproj.proj import Proj, pj_list  # noqa: F401 pylint: disable=unused-impor
 from pyproj.transformer import (  # noqa: F401 pylint: disable=unused-import
     Transformer,
     itransform,
-    proj_version_str,
     transform,
 )
 
-__version__ = "3.4.1"
+__version__ = "3.7.1"
 __all__ = [
     "Proj",
     "Geod",
@@ -82,12 +87,10 @@ __all__ = [
     "get_units_map",
     "show_versions",
 ]
-__proj_version__ = proj_version_str
-
-
+__proj_version__ = PROJ_VERSION_STR
+proj_version_str = PROJ_VERSION_STR  # pylint: disable=invalid-name
+__proj_compiled_version__ = PROJ_COMPILED_VERSION_STR
 try:
-    _pyproj_global_context_initialize()
+    pyproj.network.set_ca_bundle_path()
 except DataDirError as err:
     warnings.warn(str(err))
-
-pyproj.network.set_ca_bundle_path()
