@@ -1,6 +1,7 @@
 """
 The transformer module is for performing cartographic transformations.
 """
+
 __all__ = [
     "transform",
     "itransform",
@@ -12,19 +13,20 @@ import threading
 import warnings
 from abc import ABC, abstractmethod
 from array import array
+from collections.abc import Iterable, Iterator
 from dataclasses import dataclass
 from itertools import chain, islice
 from pathlib import Path
-from typing import Any, Dict, Iterable, Iterator, List, Optional, Tuple, Union, overload
+from typing import Any, overload
 
 from pyproj import CRS
 from pyproj._compat import cstrencode
+from pyproj._context import _clear_proj_error
 from pyproj._crs import AreaOfUse, CoordinateOperation
 from pyproj._transformer import (  # noqa: F401 pylint: disable=unused-import
     AreaOfInterest,
     _Transformer,
     _TransformerGroup,
-    proj_version_str,
 )
 from pyproj.datadir import get_user_data_dir
 from pyproj.enums import ProjVersion, TransformDirection, WktVersion
@@ -87,11 +89,12 @@ class TransformerFromCRS(  # pylint: disable=too-many-instance-attributes
     crs_from: bytes
     crs_to: bytes
     always_xy: bool
-    area_of_interest: Optional[AreaOfInterest]
-    authority: Optional[str]
-    accuracy: Optional[str]
-    allow_ballpark: Optional[bool]
+    area_of_interest: AreaOfInterest | None
+    authority: str | None
+    accuracy: str | None
+    allow_ballpark: bool | None
     force_over: bool = False
+    only_best: bool | None = None
 
     def __call__(self) -> _Transformer:
         """
@@ -108,6 +111,7 @@ class TransformerFromCRS(  # pylint: disable=too-many-instance-attributes
             accuracy=self.accuracy,
             allow_ballpark=self.allow_ballpark,
             force_over=self.force_over,
+            only_best=self.only_best,
         )
 
 
@@ -154,15 +158,17 @@ class TransformerGroup(_TransformerGroup):
         crs_from: Any,
         crs_to: Any,
         always_xy: bool = False,
-        area_of_interest: Optional[AreaOfInterest] = None,
-        authority: Optional[str] = None,
-        accuracy: Optional[float] = None,
+        area_of_interest: AreaOfInterest | None = None,
+        authority: str | None = None,
+        accuracy: float | None = None,
         allow_ballpark: bool = True,
+        allow_superseded: bool = False,
     ) -> None:
         """Get all possible transformations from a :obj:`pyproj.crs.CRS`
         or input used to create one.
 
         .. versionadded:: 3.4.0 authority, accuracy, allow_ballpark
+        .. versionadded:: 3.6.0 allow_superseded
 
         Parameters
         ----------
@@ -192,6 +198,10 @@ class TransformerGroup(_TransformerGroup):
         allow_ballpark: bool, default=True
             Set to False to disallow the use of Ballpark transformation
             in the candidate coordinate operations. Default is to allow.
+        allow_superseded: bool, default=False
+            Set to True to allow the use of superseded (but not deprecated)
+            transformations in the candidate coordinate operations. Default is
+            to disallow.
 
         """
         super().__init__(
@@ -202,13 +212,14 @@ class TransformerGroup(_TransformerGroup):
             authority=authority,
             accuracy=-1 if accuracy is None else accuracy,
             allow_ballpark=allow_ballpark,
+            allow_superseded=allow_superseded,
         )
         for iii, transformer in enumerate(self._transformers):
             # pylint: disable=unsupported-assignment-operation
             self._transformers[iii] = Transformer(TransformerUnsafe(transformer))
 
     @property
-    def transformers(self) -> List["Transformer"]:
+    def transformers(self) -> list["Transformer"]:
         """
         list[:obj:`Transformer`]:
             List of available :obj:`Transformer`
@@ -217,7 +228,7 @@ class TransformerGroup(_TransformerGroup):
         return self._transformers
 
     @property
-    def unavailable_operations(self) -> List[CoordinateOperation]:
+    def unavailable_operations(self) -> list[CoordinateOperation]:
         """
         list[:obj:`pyproj.crs.CoordinateOperation`]:
             List of :obj:`pyproj.crs.CoordinateOperation` that are not
@@ -234,7 +245,7 @@ class TransformerGroup(_TransformerGroup):
 
     def download_grids(
         self,
-        directory: Optional[Union[str, Path]] = None,
+        directory: str | Path | None = None,
         open_license: bool = True,
         verbose: bool = False,
     ) -> None:
@@ -313,10 +324,10 @@ class Transformer:
 
     def __init__(
         self,
-        transformer_maker: Union[TransformerMaker, None] = None,
+        transformer_maker: TransformerMaker | None = None,
     ) -> None:
         if not isinstance(transformer_maker, TransformerMaker):
-            ProjError.clear()
+            _clear_proj_error()
             raise ProjError(
                 "Transformer must be initialized using: "
                 "'from_crs' or 'from_pipeline'."
@@ -326,10 +337,10 @@ class Transformer:
         self._local.transformer = transformer_maker()
         self._transformer_maker = transformer_maker
 
-    def __getstate__(self) -> Dict[str, Any]:
+    def __getstate__(self) -> dict[str, Any]:
         return {"_transformer_maker": self._transformer_maker}
 
-    def __setstate__(self, state: Dict[str, Any]):
+    def __setstate__(self, state: dict[str, Any]):
         self.__dict__.update(state)
         self._local = TransformerLocal()
         self._local.transformer = self._transformer_maker()
@@ -419,13 +430,13 @@ class Transformer:
         return self._transformer.scope
 
     @property
-    def operations(self) -> Optional[Tuple[CoordinateOperation]]:
+    def operations(self) -> tuple[CoordinateOperation] | None:
         """
         .. versionadded:: 2.4.0
 
         Returns
         -------
-        Tuple[CoordinateOperation]:
+        tuple[CoordinateOperation]:
             The operations in a concatenated operation.
         """
         return self._transformer.operations
@@ -460,13 +471,13 @@ class Transformer:
         return self._transformer.is_network_enabled
 
     @property
-    def source_crs(self) -> Optional[CRS]:
+    def source_crs(self) -> CRS | None:
         """
         .. versionadded:: 3.3.0
 
         Returns
         -------
-        Optional[CRS]:
+        CRS | None:
             The source CRS of a CoordinateOperation.
         """
         return (
@@ -476,13 +487,13 @@ class Transformer:
         )
 
     @property
-    def target_crs(self) -> Optional[CRS]:
+    def target_crs(self) -> CRS | None:
         """
         .. versionadded:: 3.3.0
 
         Returns
         -------
-        Optional[CRS]:
+        CRS | None:
             The target CRS of a CoordinateOperation.
         """
         return (
@@ -496,7 +507,7 @@ class Transformer:
         proj_from: Any,
         proj_to: Any,
         always_xy: bool = False,
-        area_of_interest: Optional[AreaOfInterest] = None,
+        area_of_interest: AreaOfInterest | None = None,
     ) -> "Transformer":
         """Make a Transformer from a :obj:`pyproj.Proj` or input used to create one.
 
@@ -543,11 +554,12 @@ class Transformer:
         crs_from: Any,
         crs_to: Any,
         always_xy: bool = False,
-        area_of_interest: Optional[AreaOfInterest] = None,
-        authority: Optional[str] = None,
-        accuracy: Optional[float] = None,
-        allow_ballpark: Optional[bool] = None,
+        area_of_interest: AreaOfInterest | None = None,
+        authority: str | None = None,
+        accuracy: float | None = None,
+        allow_ballpark: bool | None = None,
         force_over: bool = False,
+        only_best: bool | None = None,
     ) -> "Transformer":
         """Make a Transformer from a :obj:`pyproj.crs.CRS` or input used to create one.
 
@@ -560,6 +572,7 @@ class Transformer:
         .. versionadded:: 2.3.0 area_of_interest
         .. versionadded:: 3.1.0 authority, accuracy, allow_ballpark
         .. versionadded:: 3.4.0 force_over
+        .. versionadded:: 3.5.0 only_best
 
         Parameters
         ----------
@@ -591,6 +604,18 @@ class Transformer:
         force_over: bool, default=False
             If True, it will to force the +over flag on the transformation.
             Requires PROJ 9+.
+        only_best: bool, optional
+            Can be set to True to cause PROJ to error out if the best
+            transformation known to PROJ and usable by PROJ if all grids known and
+            usable by PROJ were accessible, cannot be used. Best transformation should
+            be understood as the transformation returned by
+            :c:func:`proj_get_suggested_operation` if all known grids were
+            accessible (either locally or through network).
+            Note that the default value for this option can be also set with the
+            :envvar:`PROJ_ONLY_BEST_DEFAULT` environment variable, or with the
+            ``only_best_default`` setting of :ref:`proj-ini`.
+            The only_best kwarg overrides the default value if set.
+            Requires PROJ 9.2+.
 
         Returns
         -------
@@ -607,6 +632,7 @@ class Transformer:
                 accuracy=accuracy if accuracy is None else str(accuracy),
                 allow_ballpark=allow_ballpark,
                 force_over=force_over,
+                only_best=only_best,
             )
         )
 
@@ -649,32 +675,30 @@ class Transformer:
         return Transformer(TransformerFromPipeline(cstrencode(proj_pipeline)))
 
     @overload
-    def transform(  # pylint: disable=invalid-name
+    def transform(  # noqa: E704 pylint: disable=invalid-name
         self,
         xx: Any,
         yy: Any,
         radians: bool = False,
         errcheck: bool = False,
-        direction: Union[TransformDirection, str] = TransformDirection.FORWARD,
+        direction: TransformDirection | str = TransformDirection.FORWARD,
         inplace: bool = False,
-    ) -> Tuple[Any, Any]:
-        ...
+    ) -> tuple[Any, Any]: ...
 
     @overload
-    def transform(  # pylint: disable=invalid-name
+    def transform(  # noqa: E704 pylint: disable=invalid-name
         self,
         xx: Any,
         yy: Any,
         zz: Any,
         radians: bool = False,
         errcheck: bool = False,
-        direction: Union[TransformDirection, str] = TransformDirection.FORWARD,
+        direction: TransformDirection | str = TransformDirection.FORWARD,
         inplace: bool = False,
-    ) -> Tuple[Any, Any, Any]:
-        ...
+    ) -> tuple[Any, Any, Any]: ...
 
     @overload
-    def transform(  # pylint: disable=invalid-name
+    def transform(  # noqa: E704 pylint: disable=invalid-name
         self,
         xx: Any,
         yy: Any,
@@ -682,10 +706,9 @@ class Transformer:
         tt: Any,
         radians: bool = False,
         errcheck: bool = False,
-        direction: Union[TransformDirection, str] = TransformDirection.FORWARD,
+        direction: TransformDirection | str = TransformDirection.FORWARD,
         inplace: bool = False,
-    ) -> Tuple[Any, Any, Any, Any]:
-        ...
+    ) -> tuple[Any, Any, Any, Any]: ...
 
     def transform(  # pylint: disable=invalid-name
         self,
@@ -789,6 +812,19 @@ class Transformer:
         '33  98'
 
         """
+        try:
+            # function optimized for point data
+            return self._transformer._transform_point(
+                inx=xx,
+                iny=yy,
+                inz=zz,
+                intime=tt,
+                direction=direction,
+                radians=radians,
+                errcheck=errcheck,
+            )
+        except TypeError:
+            pass
         # process inputs, making copies that support buffer API.
         inx, x_data_type = _copytobuffer(xx, inplace=inplace)
         iny, y_data_type = _copytobuffer(yy, inplace=inplace)
@@ -802,8 +838,8 @@ class Transformer:
             intime = None
         # call pj_transform.  inx,iny,inz buffers modified in place.
         self._transformer._transform(
-            inx,
-            iny,
+            inx=inx,
+            iny=iny,
             inz=inz,
             intime=intime,
             direction=direction,
@@ -813,10 +849,10 @@ class Transformer:
         # if inputs were lists, tuples or floats, convert back.
         outx = _convertback(x_data_type, inx)
         outy = _convertback(y_data_type, iny)
-        return_data: Tuple[Any, ...] = (outx, outy)
-        if inz is not None:
+        return_data: tuple[Any, ...] = (outx, outy)
+        if zz is not None:
             return_data += (_convertback(z_data_type, inz),)
-        if intime is not None:
+        if tt is not None:
             return_data += (_convertback(t_data_type, intime),)
         return return_data
 
@@ -827,7 +863,7 @@ class Transformer:
         time_3rd: bool = False,
         radians: bool = False,
         errcheck: bool = False,
-        direction: Union[TransformDirection, str] = TransformDirection.FORWARD,
+        direction: TransformDirection | str = TransformDirection.FORWARD,
     ) -> Iterator[Iterable]:
         """
         Iterator/generator version of the function pyproj.Transformer.transform.
@@ -946,8 +982,7 @@ class Transformer:
                 errcheck=errcheck,
             )
 
-            for point in zip(*([iter(buff)] * stride)):
-                yield point
+            yield from zip(*([iter(buff)] * stride))
 
     def transform_bounds(
         self,
@@ -958,8 +993,8 @@ class Transformer:
         densify_pts: int = 21,
         radians: bool = False,
         errcheck: bool = False,
-        direction: Union[TransformDirection, str] = TransformDirection.FORWARD,
-    ) -> Tuple[float, float, float, float]:
+        direction: TransformDirection | str = TransformDirection.FORWARD,
+    ) -> tuple[float, float, float, float]:
         """
         .. versionadded:: 3.1.0
 
@@ -1033,7 +1068,7 @@ class Transformer:
 
     def to_proj4(
         self,
-        version: Union[ProjVersion, str] = ProjVersion.PROJ_5,
+        version: ProjVersion | str = ProjVersion.PROJ_5,
         pretty: bool = False,
     ) -> str:
         """
@@ -1059,7 +1094,7 @@ class Transformer:
 
     def to_wkt(
         self,
-        version: Union[WktVersion, str] = WktVersion.WKT2_2019,
+        version: WktVersion | str = WktVersion.WKT2_2019,
         pretty: bool = False,
     ) -> str:
         """
@@ -1132,7 +1167,7 @@ class Transformer:
             f"Area of Use:\n{self.area_of_use or '- undefined'}"
         )
 
-    def __eq__(self, other: Any) -> bool:
+    def __eq__(self, other: object) -> bool:
         if not isinstance(other, Transformer):
             return False
         return self._transformer.__eq__(other._transformer)
@@ -1160,8 +1195,8 @@ def transform(  # pylint: disable=invalid-name
     p2: Any,
     x: Any,
     y: Any,
-    z: Optional[Any] = None,
-    tt: Optional[Any] = None,
+    z: Any | None = None,
+    tt: Any | None = None,
     radians: bool = False,
     errcheck: bool = False,
     always_xy: bool = False,
@@ -1205,39 +1240,6 @@ def transform(  # pylint: disable=invalid-name
     geocentric coordinates, values of x and y are given in meters.
     z is always meters.
 
-    Example usage:
-
-    >>> from pyproj import Proj, transform
-    >>> # projection 1: UTM zone 15, grs80 ellipse, NAD83 datum
-    >>> # (defined by epsg code 26915)
-    >>> p1 = Proj('epsg:26915', preserve_units=False)
-    >>> # projection 2: UTM zone 15, clrk66 ellipse, NAD27 datum
-    >>> p2 = Proj('epsg:26715', preserve_units=False)
-    >>> # find x,y of Jefferson City, MO.
-    >>> x1, y1 = p1(-92.199881,38.56694)
-    >>> # transform this point to projection 2 coordinates.
-    >>> x2, y2 = transform(p1,p2,x1,y1)
-    >>> '%9.3f %11.3f' % (x1,y1)
-    '569704.566 4269024.671'
-    >>> '%9.3f %11.3f' % (x2,y2)
-    '569722.342 4268814.028'
-    >>> '%8.3f %5.3f' % p2(x2,y2,inverse=True)
-    ' -92.200 38.567'
-    >>> # process 3 points at a time in a tuple
-    >>> lats = (38.83,39.32,38.75) # Columbia, KC and StL Missouri
-    >>> lons = (-92.22,-94.72,-90.37)
-    >>> x1, y1 = p1(lons,lats)
-    >>> x2, y2 = transform(p1,p2,x1,y1)
-    >>> xy = x1+y1
-    >>> '%9.3f %9.3f %9.3f %11.3f %11.3f %11.3f' % xy
-    '567703.344 351730.944 728553.093 4298200.739 4353698.725 4292319.005'
-    >>> xy = x2+y2
-    >>> '%9.3f %9.3f %9.3f %11.3f %11.3f %11.3f' % xy
-    '567721.149 351747.558 728569.133 4297989.112 4353489.645 4292106.305'
-    >>> lons, lats = p2(x2,y2,inverse=True)
-    >>> xy = lons+lats
-    >>> '%8.3f %8.3f %8.3f %5.3f %5.3f %5.3f' % xy
-    ' -92.220  -94.720  -90.370 38.830 39.320 38.750'
     """
     warnings.warn(
         (
