@@ -18,7 +18,7 @@ from pyproj.crs.coordinate_operation import (
     VerticalPerspectiveConversion,
 )
 from pyproj.exceptions import CRSError
-from test.conftest import PROJ_GTE_901, PROJ_LOOSE_VERSION
+from test.conftest import PROJ_LOOSE_VERSION
 
 
 def _to_dict(operation):
@@ -82,13 +82,9 @@ def test_to_cf_transverse_mercator():
     )
     towgs84_test = [-122.74, -34.27, -22.83, -1.884, -3.4, -3.03, -15.62]
     horizontal_datum_name = (
-        "Unknown based on International 1924 (Hayford 1909, 1910) ellipsoid"
+        "Unknown based on International 1924 (Hayford 1909, 1910) ellipsoid using "
+        "towgs84=-122.74,-34.27,-22.83,-1.884,-3.400,-3.030,-15.62"
     )
-    if PROJ_GTE_901:
-        horizontal_datum_name = (
-            f"{horizontal_datum_name} using "
-            "towgs84=-122.74,-34.27,-22.83,-1.884,-3.400,-3.030,-15.62"
-        )
     expected_cf = {
         "semi_major_axis": 6378388.0,
         "semi_minor_axis": crs.ellipsoid.semi_minor_metre,
@@ -1868,16 +1864,16 @@ def test_export_compound_crs_cs():
 
 def test_ellipsoidal_cs__geodetic():
     crs = CRS.from_epsg(4326)
-    crs.cs_to_cf() == [
+    assert crs.cs_to_cf() == [
         {
             "standard_name": "latitude",
-            "long_name": "geodetic latitude coordinate",
+            "long_name": "latitude coordinate",
             "units": "degrees_north",
             "axis": "Y",
         },
         {
             "standard_name": "longitude",
-            "long_name": "geodetic longitude coordinate",
+            "long_name": "longitude coordinate",
             "units": "degrees_east",
             "axis": "X",
         },
@@ -1939,16 +1935,16 @@ def test_3d_ellipsoidal_cs_depth():
             },
         }
     )
-    crs.cs_to_cf() == [
+    assert crs.cs_to_cf() == [
         {
             "standard_name": "latitude",
-            "long_name": "geodetic latitude coordinate",
+            "long_name": "latitude coordinate",
             "units": "degrees_north",
             "axis": "Y",
         },
         {
             "standard_name": "longitude",
-            "long_name": "geodetic longitude coordinate",
+            "long_name": "longitude coordinate",
             "units": "degrees_east",
             "axis": "X",
         },
