@@ -69,7 +69,7 @@ def test_awips221():
     )
     t2 = perf_counter()
     print("data in lists:")
-    print("compute lats/lons for all points on AWIPS 221 grid ({}x{})".format(nx, ny))
+    print(f"compute lats/lons for all points on AWIPS 221 grid ({nx}x{ny})")
     print("max/min lons")
     print(min(lons), max(lons))
     print("max/min lats")
@@ -81,7 +81,7 @@ def test_awips221():
     lons, lats = awips221(xa, ya, inverse=True)
     t2 = perf_counter()
     print("data in python arrays:")
-    print("compute lats/lons for all points on AWIPS 221 grid ({}x{})".format(nx, ny))
+    print(f"compute lats/lons for all points on AWIPS 221 grid ({nx}x{ny})")
     print("max/min lons")
     print(min(lons), max(lons))
     print("max/min lats")
@@ -91,7 +91,7 @@ def test_awips221():
     lons, lats = awips221(x, y, inverse=True)
     t2 = perf_counter()
     print("data in a numpy array:")
-    print("compute lats/lons for all points on AWIPS 221 grid ({}x{})".format(nx, ny))
+    print(f"compute lats/lons for all points on AWIPS 221 grid ({nx}x{ny})")
     print("max/min lons")
     print(
         numpy.minimum.reduce(numpy.ravel(lons)), numpy.maximum.reduce(numpy.ravel(lons))
